pub enum ProviderError {
SerdeJsonError(Error),
EncoderError(EncodingError),
CoinsSerError(SerError),
Unsupported(String),
RpcErrorResponse(ErrorResponse),
Custom {
from_parsing: bool,
e: Box<dyn Error>,
},
}Expand description
Errors thrown by providers
Variants
SerdeJsonError(Error)
Serde issue
EncoderError(EncodingError)
Bubbled up from bitcoins
CoinsSerError(SerError)
Bubbled up from core
Unsupported(String)
Unsupported action. Provider should give a string describing the action and reason
RpcErrorResponse(ErrorResponse)
RPC Error Response
Custom
Custom provider error. Indicates whether the request should be retried
Implementations
Sourceimpl ProviderError
impl ProviderError
Sourcepub fn custom(from_parsing: bool, e: Box<dyn Error>) -> Self
pub fn custom(from_parsing: bool, e: Box<dyn Error>) -> Self
Shortcut for instantiating a custom error
Sourcepub fn from_parsing(&self) -> bool
pub fn from_parsing(&self) -> bool
Returns true if the request failed due to a local parsing error.
Note:
This usually indicates that a requested object was not found. It is common for Bitcoin APIs to violate JSON RPC conventions, and return raw strings in this case.